@@ -4,11 +4,11 @@ use strict;
 
 package Data::Tabular::Output::HTML;
 
-use Time::HiRes qw ( gettimeofday tv_interval );
+use base 'Data::Tabular::Output';
 
 use Carp qw (croak);
 
-use overload '""' => \&render;
+use overload '""' => \&_render;
 
 sub new
 {
@@ -19,52 +19,15 @@ sub new
 
     die 'No table' unless $args->{table};
     $self->{table} = $args->{table};
-
-    $self->{output} = $args->{output} || $self->{table}->_output;
+    die 'No output config' unless $args->{output};
+    die 'No output config' unless ref $args->{output};
+    die 'No output config' unless $args->{output}->isa('Data::Tabular::Config::Output');
+    $self->{output} = $args->{output};
 
     $self;
 }
 
-sub output
-{
-    my $self = shift;
-    $self->{output};
-}
-
-sub columns
-{
-    my $self = shift;
-
-    $self->{table}->columns;
-}
-
-sub rows
-{
-    my $self = shift;
-    $self->{table}->rows(output => $self->output);
-}
-
-sub attrib
-{
-     my $self = shift;
-
- warn $self->output;
- warn keys %{$self->output};
-
-if (my $href = $self->output->{html}) {
-warn 'HRef ', $href;
-     $href->{attributes} = {};
-     my $new_attributes = {
-	 %{$href->{attributes}},
-	 @_,
-     };
-     $href->{attributes} = $new_attributes;
- }
-
-     $self;
-}
-
-sub render
+sub _render
 {
     my $self = shift;
     $self->html;
@@ -74,20 +37,31 @@ sub html
 {
     my $self = shift;
 
+    my $output = $self->output;
     my $attributes = $self->output->html_attribute_string;
 
     $attributes .= '';
     my $ret = "<table$attributes>\n";
 
     for my $col ($self->columns()) {
-	my $attribute = $col->html_attribute_string;
+        my $attribute = $col->align();
+#FIXME
         $ret .= " <colgroup$attribute>\n";
     }
-
     my @table;
+    if ($output->table) {
+# FIX me -- it would be better to put a Title row on the top of the table.
+	for my $col ($self->columns()) {
+	    push(@table, "  <th$attributes>");
+	    push(@table, $col->name());
+	    push(@table, "</th>\n");
+        }
+    }
+
     for my $row ($self->rows()) {
 	my $attribute = $row->html_attribute_string();
         push(@table, " <tr$attribute>\n");
+#	push(@table, "<td>", ref $row, "</td>\n");
 	for my $cell ($row->cells()) {
 	    my $attributes = $cell->html_attribute_string;
 	    my $hdr = $cell->hdr;
@@ -97,7 +71,7 @@ sub html
 		push(@table, "  <td$attributes>");
 	    }
             my $cell_data = $cell->html_string;
-	    $cell_data =~ s/^\s*(.*)\s*$/$1/;
+#	    $cell_data =~ s/^\s*(.*)\s*$/$1/;
 	    if (length($cell_data) == 0) {
 	       $cell_data = '<br>';
 	    }
@@ -108,6 +82,7 @@ sub html
 		push(@table, "</td>\n");
 	    }
 	}
+	push(@table, " </tr>\n");
     }
     $ret .= join('', @table);
     $ret .= "</table>\n";
@@ -119,20 +94,41 @@ __END__
 
 =head1 NAME
 
-Data::Tabular::Output;
+Data::Tabular::Output::HTML;
 
 =head1 SYNOPSIS
 
-This object is used by Data::Tabular to render a table.
+This object is used by Data::Tabular to render an HTML table.
 
 =head1 DESCRIPTION
 
-=head1 METHODS
+This object takes a Table and an output object and return an HTML table.
+
+ my $table = Data::Tabular::Output::HTML->new(table => $t, output => $o);
+ print $table;
+
+Note that if the object is used as a string the table is rendered.
+
+=head1 CONSTRUCTOR
 
 =over 4
 
 =item new
 
+Normally this object is constructed by the Data::Tabular::html method.
+
+It requires two arguments: a table and and an output object.
+
+=back
+
+=head1 METHODS
+
+=over 4
+
+=item html
+
+This method returns a string that is an HTML table.
+
 =cut
 1;
 
